#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-EDsi359Zelb3bs0aS3Netj
key:                  ghcide-2.3.0.0-EDsi359Zelb3bs0aS3Netj
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  c45943841a087a44353bcd46efdaafb2
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-EDsi359Zelb3bs0aS3Netj
depends:
    Diff-0.5-1NGQ2AwAw3pDIUtg9aS2pi Glob-0.10.2-JgU70AV9J1Z9hdsqakOSol
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy array-0.5.6.0
    async-2.2.5-FIWsXw8tceP2d6lj6DHM5i base-4.18.2.1
    base16-bytestring-1.0.2.0-BqWVRU1IQoAP0y3rqebgF binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-77TInwzUoLr4ZTB9XsbUbo
    co-log-core-0.3.2.6-4F32CECC6UP7vyDdwlWkoE containers-0.6.7
    cryptohash-sha1-0.11.101.0-8dJHersgxE5IzFukHOmBgd
    data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297 deepseq-1.4.8.1
    dependent-map-0.4.0.1-1cylMDanTHbBj8I8BH43Xr
    dependent-sum-0.7.2.0-4QzLyGVEPq6G1odn3LdjP7 directory-1.3.8.5
    dlist-1.0-3kgMz6KIk692BOWE28VQNd
    enummapset-0.7.3.0-5wUycQZbrnH4hU8T7wF4IN exceptions-0.10.7
    extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE filepath-1.4.300.1
    fingertree-0.1.6.2-9sOcWB5cvDsAFE73AC95jv
    focus-1.0.3.2-5wMFTlPYsnyCp8GkFC0kVk ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-HjhgxpJ0Vxu7pNRjPmgsZP
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-1h8Xqq2esX8AplM4zvAxvp
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    hie-bios-0.12.0-7FDkR03hAPzHCr8RTUg5IT
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-6FTQK0n5cKzGjQUWEMQrOC
    hls-graph-2.3.0.0-L5JwZbxYZhpLMxa0Lo1rrE
    hls-plugin-api-2.3.0.0-AcIoZlqPhQDHyGB3lRYzhI
    implicit-hie-0.1.4.0-5MJR2t4o8ZS3qPO7rmigC0
    implicit-hie-cradle-0.5.0.1-CCXQ5Jtl1agAK2Natu4pUL
    lens-5.3.4-IAs8Kog1h7NBhXd2ts4yf7
    list-t-1.0.5.7-I3J9qWmojUP5OTwbclTBr5
    lsp-2.2.0.0-JDUsVH21zrK9Rv29N3FIZb
    lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo mtl-2.3.1
    opentelemetry-0.8.0-GYAu9PY1nDi4fwNxgtJXd
    optparse-applicative-0.18.1.0-7EdJH1WM84m2Q8FpgsqIZk
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-6jg14vIwDos4Lqu7eMpEik
    prettyprinter-ansi-terminal-1.1.3-25dNCVEFp3dGuk7ZV0yUf5
    random-1.2.1.3-3jem7NfN1E34SkjZGu3Vjy
    regex-tdfa-1.3.2.5-2Z48wQLqPnRDongr7ozo6M
    row-types-1.0.1.2-2FA6VL7KxweLkHrr9o9yHn
    safe-exceptions-0.1.7.4-AkFQpeQZgUZ5VDqbpLWXE4
    sorted-list-0.2.3.1-6RZt8PqJUKL2QToeSYZR8m
    sqlite-simple-0.4.19.0-7ZTyYORLh4cDQ5X1tlptLE stm-2.5.1.0
    stm-containers-1.2.1.1-KTAi11CJlOQ9TCpSUOdftx
    syb-0.7.3-L7kiOZAm9FuLsEbHYQuF8P text-2.0.2
    text-rope-0.3-13PtxrxbfWSEznkenTV65t time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-5TDFrh4ofEEIRD14KRsITD
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

